Eugene-commits
Threads by month
- ----- 2026 -----
- June
- May
- April
- March
- February
- January
- ----- 2025 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2024 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2023 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2022 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2021 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2020 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2019 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2018 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2017 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2016 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2015 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2014 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2013 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2012 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2011 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2010 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2009 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2008 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2007 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2006 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2005 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2004 -----
- December
- November
- October
- September
- August
July 2013
- 4 participants
- 13 discussions
r1293 - in trunk: . eugene eugene-java-templates eugene-maven-plugin eugene-plantuml-templates eugene-yaml-templates
by maven-release@users.nuiton.org 23 Jul '13
by maven-release@users.nuiton.org 23 Jul '13
23 Jul '13
Author: maven-release
Date: 2013-07-23 16:47:19 +0200 (Tue, 23 Jul 2013)
New Revision: 1293
Url: http://nuiton.org/projects/eugene/repository/revisions/1293
Log:
[maven-release-plugin] prepare for next development iteration
Modified:
trunk/eugene-java-templates/pom.xml
trunk/eugene-maven-plugin/pom.xml
trunk/eugene-plantuml-templates/pom.xml
trunk/eugene-yaml-templates/pom.xml
trunk/eugene/pom.xml
trunk/pom.xml
Modified: trunk/eugene/pom.xml
===================================================================
--- trunk/eugene/pom.xml 2013-07-23 14:47:16 UTC (rev 1292)
+++ trunk/eugene/pom.xml 2013-07-23 14:47:19 UTC (rev 1293)
@@ -30,7 +30,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7</version>
+ <version>2.7.1-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-java-templates/pom.xml
===================================================================
--- trunk/eugene-java-templates/pom.xml 2013-07-23 14:47:16 UTC (rev 1292)
+++ trunk/eugene-java-templates/pom.xml 2013-07-23 14:47:19 UTC (rev 1293)
@@ -28,7 +28,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7</version>
+ <version>2.7.1-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-maven-plugin/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/pom.xml 2013-07-23 14:47:16 UTC (rev 1292)
+++ trunk/eugene-maven-plugin/pom.xml 2013-07-23 14:47:19 UTC (rev 1293)
@@ -31,7 +31,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7</version>
+ <version>2.7.1-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-plantuml-templates/pom.xml
===================================================================
--- trunk/eugene-plantuml-templates/pom.xml 2013-07-23 14:47:16 UTC (rev 1292)
+++ trunk/eugene-plantuml-templates/pom.xml 2013-07-23 14:47:19 UTC (rev 1293)
@@ -28,7 +28,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7</version>
+ <version>2.7.1-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-yaml-templates/pom.xml
===================================================================
--- trunk/eugene-yaml-templates/pom.xml 2013-07-23 14:47:16 UTC (rev 1292)
+++ trunk/eugene-yaml-templates/pom.xml 2013-07-23 14:47:19 UTC (rev 1293)
@@ -28,7 +28,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7</version>
+ <version>2.7.1-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2013-07-23 14:47:16 UTC (rev 1292)
+++ trunk/pom.xml 2013-07-23 14:47:19 UTC (rev 1293)
@@ -34,7 +34,7 @@
</parent>
<artifactId>eugene</artifactId>
- <version>2.7</version><!-- ************************************************************* -->
+ <version>2.7.1-SNAPSHOT</version><!-- ************************************************************* -->
<!-- *** Build Settings ****************************************** -->
<!-- ************************************************************* -->
<packaging>pom</packaging>
@@ -139,11 +139,11 @@
<!-- Source control management. -->
<scm>
- <connection>scm:svn:http://svn.nuiton.org/svn/eugene/tags/eugene-2.7</connection>
+ <connection>scm:svn:http://svn.nuiton.org/svn/eugene/trunk</connection>
<developerConnection>
- scm:svn:http://svn.nuiton.org/svn/eugene/tags/eugene-2.7
+ scm:svn:http://svn.nuiton.org/svn/eugene/trunk
</developerConnection>
- <url>http://nuiton.org/projects/eugene/repository/show/tags/eugene-2.7</url>
+ <url>http://nuiton.org/projects/eugene/repository/show/trunk</url>
</scm>
<distributionManagement>
<site>
1
0
Author: maven-release
Date: 2013-07-23 16:47:16 +0200 (Tue, 23 Jul 2013)
New Revision: 1292
Url: http://nuiton.org/projects/eugene/repository/revisions/1292
Log:
[maven-release-plugin] copy for tag eugene-2.7
Added:
tags/eugene-2.7/
Property changes on: tags/eugene-2.7
___________________________________________________________________
Added: svn:ignore
+ target
.settings
bin
.classpath
.project
*.iml
*.ipr
*.iws
.idea
Added: svn:mergeinfo
+ /branches/1.0.1-Javabuilder:641-651
/branches/1.1.0-Javabuilder:652-681
/branches/eugene-2.0:682-754
/branches/eugene-2.4.3:1151-1173
1
0
r1291 - in trunk: . eugene eugene-java-templates eugene-maven-plugin eugene-plantuml-templates eugene-yaml-templates
by maven-release@users.nuiton.org 23 Jul '13
by maven-release@users.nuiton.org 23 Jul '13
23 Jul '13
Author: maven-release
Date: 2013-07-23 16:47:12 +0200 (Tue, 23 Jul 2013)
New Revision: 1291
Url: http://nuiton.org/projects/eugene/repository/revisions/1291
Log:
[maven-release-plugin] prepare release eugene-2.7
Modified:
trunk/eugene-java-templates/pom.xml
trunk/eugene-maven-plugin/pom.xml
trunk/eugene-plantuml-templates/pom.xml
trunk/eugene-yaml-templates/pom.xml
trunk/eugene/pom.xml
trunk/pom.xml
Modified: trunk/eugene/pom.xml
===================================================================
--- trunk/eugene/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
+++ trunk/eugene/pom.xml 2013-07-23 14:47:12 UTC (rev 1291)
@@ -30,7 +30,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7-SNAPSHOT</version>
+ <version>2.7</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-java-templates/pom.xml
===================================================================
--- trunk/eugene-java-templates/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
+++ trunk/eugene-java-templates/pom.xml 2013-07-23 14:47:12 UTC (rev 1291)
@@ -28,7 +28,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7-SNAPSHOT</version>
+ <version>2.7</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-maven-plugin/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
+++ trunk/eugene-maven-plugin/pom.xml 2013-07-23 14:47:12 UTC (rev 1291)
@@ -31,7 +31,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7-SNAPSHOT</version>
+ <version>2.7</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-plantuml-templates/pom.xml
===================================================================
--- trunk/eugene-plantuml-templates/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
+++ trunk/eugene-plantuml-templates/pom.xml 2013-07-23 14:47:12 UTC (rev 1291)
@@ -28,7 +28,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7-SNAPSHOT</version>
+ <version>2.7</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-yaml-templates/pom.xml
===================================================================
--- trunk/eugene-yaml-templates/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
+++ trunk/eugene-yaml-templates/pom.xml 2013-07-23 14:47:12 UTC (rev 1291)
@@ -28,7 +28,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.7-SNAPSHOT</version>
+ <version>2.7</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
+++ trunk/pom.xml 2013-07-23 14:47:12 UTC (rev 1291)
@@ -34,7 +34,7 @@
</parent>
<artifactId>eugene</artifactId>
- <version>2.7-SNAPSHOT</version><!-- ************************************************************* -->
+ <version>2.7</version><!-- ************************************************************* -->
<!-- *** Build Settings ****************************************** -->
<!-- ************************************************************* -->
<packaging>pom</packaging>
@@ -139,11 +139,11 @@
<!-- Source control management. -->
<scm>
- <connection>scm:svn:http://svn.nuiton.org/svn/eugene/trunk</connection>
+ <connection>scm:svn:http://svn.nuiton.org/svn/eugene/tags/eugene-2.7</connection>
<developerConnection>
- scm:svn:http://svn.nuiton.org/svn/eugene/trunk
+ scm:svn:http://svn.nuiton.org/svn/eugene/tags/eugene-2.7
</developerConnection>
- <url>http://nuiton.org/projects/eugene/repository/show/trunk</url>
+ <url>http://nuiton.org/projects/eugene/repository/show/tags/eugene-2.7</url>
</scm>
<distributionManagement>
<site>
1
0
r1290 - in trunk: . eugene eugene/src/license eugene-java-templates eugene-java-templates/src/license eugene-maven-plugin eugene-maven-plugin/src/license eugene-plantuml-templates eugene-plantuml-templates/src eugene-plantuml-templates/src/license eugene-yaml-templates eugene-yaml-templates/src eugene-yaml-templates/src/license
by tchemit@users.nuiton.org 23 Jul '13
by tchemit@users.nuiton.org 23 Jul '13
23 Jul '13
Author: tchemit
Date: 2013-07-23 16:45:53 +0200 (Tue, 23 Jul 2013)
New Revision: 1290
Url: http://nuiton.org/projects/eugene/repository/revisions/1290
Log:
optimize pom (using tidy:pom)
optimize third-party
Added:
trunk/eugene-plantuml-templates/src/license/
trunk/eugene-plantuml-templates/src/license/THIRD-PARTY.properties
trunk/eugene-yaml-templates/src/license/
trunk/eugene-yaml-templates/src/license/THIRD-PARTY.properties
Modified:
trunk/eugene-java-templates/pom.xml
trunk/eugene-java-templates/src/license/THIRD-PARTY.properties
trunk/eugene-maven-plugin/pom.xml
trunk/eugene-maven-plugin/src/license/THIRD-PARTY.properties
trunk/eugene-plantuml-templates/LICENSE.txt
trunk/eugene-plantuml-templates/pom.xml
trunk/eugene-yaml-templates/LICENSE.txt
trunk/eugene-yaml-templates/pom.xml
trunk/eugene/pom.xml
trunk/eugene/src/license/THIRD-PARTY.properties
trunk/pom.xml
Modified: trunk/eugene/pom.xml
===================================================================
--- trunk/eugene/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
@@ -23,10 +23,8 @@
#L%
-->
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
-
<modelVersion>4.0.0</modelVersion>
-
- <!-- ************************************************************* -->
+<!-- ************************************************************* -->
<!-- *** POM Relationships *************************************** -->
<!-- ************************************************************* -->
<parent>
@@ -37,8 +35,20 @@
<groupId>org.nuiton.eugene</groupId>
<artifactId>eugene</artifactId>
-
- <!-- POM Relationships : Inheritance : Dependencies -->
+<!-- ************************************************************* -->
+ <!-- *** Project Information ************************************* -->
+ <!-- ************************************************************* -->
+ <name>EUGene :: EUGene</name>
+ <description>Efficient Universal Generator.</description>
+ <inceptionYear>2004</inceptionYear>
+<!-- ************************************************************* -->
+ <!-- *** Build Settings ****************************************** -->
+ <!-- ************************************************************* -->
+ <properties>
+ <!-- extra files to include in release -->
+ <redmine.releaseFiles>${redmine.libReleaseFiles}</redmine.releaseFiles>
+ </properties>
+<!-- POM Relationships : Inheritance : Dependencies -->
<dependencies>
<dependency>
@@ -130,25 +140,7 @@
</dependencies>
- <!-- ************************************************************* -->
- <!-- *** Project Information ************************************* -->
- <!-- ************************************************************* -->
- <name>EUGene :: EUGene</name>
-
- <description>Efficient Universal Generator.</description>
- <inceptionYear>2004</inceptionYear>
-
- <!-- ************************************************************* -->
- <!-- *** Build Settings ****************************************** -->
- <!-- ************************************************************* -->
-
- <properties>
- <!-- extra files to include in release -->
- <redmine.releaseFiles>${redmine.libReleaseFiles}</redmine.releaseFiles>
- </properties>
-
<build>
-
<resources>
<resource>
<directory>${basedir}/src/main/xsl</directory>
@@ -163,7 +155,6 @@
</includes>
</resource>
</resources>
-
<plugins>
<plugin>
<groupId>org.nuiton.processor</groupId>
@@ -197,13 +188,10 @@
</executions>
</plugin>
</plugins>
-
</build>
-
- <!-- ************************************************************* -->
+<!-- ************************************************************* -->
<!-- *** Build Environment ************************************** -->
<!-- ************************************************************* -->
-
<profiles>
<!-- prepare release assemblies at release time -->
<profile>
@@ -265,8 +253,4 @@
</profile>
</profiles>
-
</project>
-
-
-
Modified: trunk/eugene/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/eugene/src/license/THIRD-PARTY.properties 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene/src/license/THIRD-PARTY.properties 2013-07-23 14:45:53 UTC (rev 1290)
@@ -1,8 +1,8 @@
# Generated by org.codehaus.mojo.license.AddThirdPartyMojo
#-------------------------------------------------------------------------------
# Already used licenses in project :
+# - Apache License Version 2.0
# - BSD License
-# - BSD style
# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
# - Common Public License Version 1.0
# - Eclipse Public License - v 1.0
@@ -12,15 +12,14 @@
# - Lesser General Public License (LPGL) v 2.1
# - MIT License
# - Mozilla Public License Version 1.0
+# - New BSD License
# - The Apache Software License, Version 2.0
# - The SAX License
# - The W3C License
-# - The Werken Company License
+# - http://jaxen.codehaus.org/license.html
#-------------------------------------------------------------------------------
# Please fill the missing licenses for dependencies :
#
#
-#Mon May 28 11:02:25 CEST 2012
+#Tue Jul 23 16:39:14 CEST 2013
commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
-dom4j--dom4j--1.6.1=BSD License
-jdom--jdom--1.0=The Apache Software License, Version 2.0
Modified: trunk/eugene-java-templates/pom.xml
===================================================================
--- trunk/eugene-java-templates/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene-java-templates/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
@@ -23,7 +23,6 @@
#L%
-->
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
-
<modelVersion>4.0.0</modelVersion>
<parent>
@@ -35,6 +34,14 @@
<groupId>org.nuiton.eugene</groupId>
<artifactId>eugene-java-templates</artifactId>
+ <name>EUGene :: Java templates</name>
+ <inceptionYear>2012</inceptionYear>
+
+ <properties>
+ <!-- extra files to include in release -->
+ <redmine.releaseFiles>${redmine.libReleaseFiles}</redmine.releaseFiles>
+ </properties>
+
<dependencies>
<dependency>
@@ -71,17 +78,7 @@
</dependencies>
- <name>EUGene :: Java templates</name>
-
- <inceptionYear>2012</inceptionYear>
-
- <properties>
- <!-- extra files to include in release -->
- <redmine.releaseFiles>${redmine.libReleaseFiles}</redmine.releaseFiles>
- </properties>
-
<build>
-
<plugins>
<plugin>
<groupId>org.nuiton.processor</groupId>
@@ -115,7 +112,6 @@
</executions>
</plugin>
</plugins>
-
</build>
<profiles>
@@ -142,8 +138,4 @@
</profile>
</profiles>
-
</project>
-
-
-
Modified: trunk/eugene-java-templates/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/eugene-java-templates/src/license/THIRD-PARTY.properties 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene-java-templates/src/license/THIRD-PARTY.properties 2013-07-23 14:45:53 UTC (rev 1290)
@@ -2,7 +2,6 @@
#-------------------------------------------------------------------------------
# Already used licenses in project :
# - BSD License
-# - BSD style
# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
# - Common Public License Version 1.0
# - Indiana University Extreme! Lab Software License, vesion 1.1.1
@@ -11,15 +10,14 @@
# - Lesser General Public License (LPGL) v 2.1
# - MIT License
# - Mozilla Public License Version 1.0
+# - New BSD License
# - The Apache Software License, Version 2.0
# - The SAX License
# - The W3C License
-# - The Werken Company License
+# - http://jaxen.codehaus.org/license.html
#-------------------------------------------------------------------------------
# Please fill the missing licenses for dependencies :
#
#
-#Wed Oct 24 21:31:10 CEST 2012
+#Tue Jul 23 16:39:15 CEST 2013
commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
-dom4j--dom4j--1.6.1=BSD License
-jdom--jdom--1.0=The Apache Software License, Version 2.0
Modified: trunk/eugene-maven-plugin/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene-maven-plugin/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
@@ -24,10 +24,8 @@
-->
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
-
<modelVersion>4.0.0</modelVersion>
-
- <!-- ************************************************************* -->
+<!-- ************************************************************* -->
<!-- *** POM Relationships *************************************** -->
<!-- ************************************************************* -->
<parent>
@@ -37,9 +35,17 @@
</parent>
<groupId>org.nuiton.eugene</groupId>
- <artifactId>eugene-maven-plugin</artifactId>
-
- <!-- POM Relationships : Inheritance : Dependencies -->
+ <artifactId>eugene-maven-plugin</artifactId><!-- ************************************************************* -->
+ <!-- *** Build Settings ****************************************** -->
+ <!-- ************************************************************* -->
+ <packaging>maven-plugin</packaging>
+<!-- ************************************************************* -->
+ <!-- *** Project Information ************************************* -->
+ <!-- ************************************************************* -->
+ <name>EUGene :: Maven plugin</name>
+ <description>Maven plugin to use the eugene library</description>
+ <inceptionYear>2006</inceptionYear>
+<!-- POM Relationships : Inheritance : Dependencies -->
<dependencies>
<dependency>
@@ -139,20 +145,7 @@
</dependencies>
- <!-- ************************************************************* -->
- <!-- *** Project Information ************************************* -->
- <!-- ************************************************************* -->
- <name>EUGene :: Maven plugin</name>
- <inceptionYear>2006</inceptionYear>
- <description>Maven plugin to use the eugene library</description>
-
- <!-- ************************************************************* -->
- <!-- *** Build Settings ****************************************** -->
- <!-- ************************************************************* -->
- <packaging>maven-plugin</packaging>
-
<build>
-
<pluginManagement>
<plugins>
@@ -173,7 +166,6 @@
</plugins>
</pluginManagement>
-
<plugins>
<!-- expose new plexus components -->
@@ -190,7 +182,6 @@
</plugin>
</plugins>
-
</build>
<profiles>
@@ -277,6 +268,4 @@
</build>
</profile>
</profiles>
-
</project>
-
Modified: trunk/eugene-maven-plugin/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/eugene-maven-plugin/src/license/THIRD-PARTY.properties 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene-maven-plugin/src/license/THIRD-PARTY.properties 2013-07-23 14:45:53 UTC (rev 1290)
@@ -1,8 +1,8 @@
# Generated by org.codehaus.mojo.license.AddThirdPartyMojo
#-------------------------------------------------------------------------------
# Already used licenses in project :
+# - Apache License Version 2.0
# - BSD License
-# - BSD style
# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
# - Common Public License Version 1.0
# - Indiana University Extreme! Lab Software License, vesion 1.1.1
@@ -11,19 +11,19 @@
# - Lesser General Public License (LPGL) v 2.1
# - MIT License
# - Mozilla Public License Version 1.0
+# - New BSD License
# - Public Domain
# - The Apache Software License, Version 2.0
+# - The GNU General Public License
# - The SAX License
# - The W3C License
-# - The Werken Company License
# - http://classworlds.codehaus.org/license.html
+# - http://jaxen.codehaus.org/license.html
#-------------------------------------------------------------------------------
# Please fill the missing licenses for dependencies :
#
#
-#Sun Nov 11 20:45:26 CET 2012
+#Tue Jul 23 16:39:51 CEST 2013
classworlds--classworlds--1.1-alpha-2=http\://classworlds.codehaus.org/lice…
commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
-dom4j--dom4j--1.6.1=BSD License
-jdom--jdom--1.0=The Apache Software License, Version 2.0
org.codehaus.plexus--plexus-container-default--1.0-alpha-9-stable-1=The Apache Software License, Version 2.0
Modified: trunk/eugene-plantuml-templates/LICENSE.txt
===================================================================
--- trunk/eugene-plantuml-templates/LICENSE.txt 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene-plantuml-templates/LICENSE.txt 2013-07-23 14:45:53 UTC (rev 1290)
@@ -0,0 +1,166 @@
+ GNU LESSER GENERAL PUBLIC LICENSE
+ Version 3, 29 June 2007
+
+ Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>
+ Everyone is permitted to copy and distribute verbatim copies
+ of this license document, but changing it is not allowed.
+
+
+ This version of the GNU Lesser General Public License incorporates
+the terms and conditions of version 3 of the GNU General Public
+License, supplemented by the additional permissions listed below.
+
+ 0. Additional Definitions.
+
+ As used herein, "this License" refers to version 3 of the GNU Lesser
+General Public License, and the "GNU GPL" refers to version 3 of the GNU
+General Public License.
+
+ "The Library" refers to a covered work governed by this License,
+other than an Application or a Combined Work as defined below.
+
+ An "Application" is any work that makes use of an interface provided
+by the Library, but which is not otherwise based on the Library.
+Defining a subclass of a class defined by the Library is deemed a mode
+of using an interface provided by the Library.
+
+ A "Combined Work" is a work produced by combining or linking an
+Application with the Library. The particular version of the Library
+with which the Combined Work was made is also called the "Linked
+Version".
+
+ The "Minimal Corresponding Source" for a Combined Work means the
+Corresponding Source for the Combined Work, excluding any source code
+for portions of the Combined Work that, considered in isolation, are
+based on the Application, and not on the Linked Version.
+
+ The "Corresponding Application Code" for a Combined Work means the
+object code and/or source code for the Application, including any data
+and utility programs needed for reproducing the Combined Work from the
+Application, but excluding the System Libraries of the Combined Work.
+
+ 1. Exception to Section 3 of the GNU GPL.
+
+ You may convey a covered work under sections 3 and 4 of this License
+without being bound by section 3 of the GNU GPL.
+
+ 2. Conveying Modified Versions.
+
+ If you modify a copy of the Library, and, in your modifications, a
+facility refers to a function or data to be supplied by an Application
+that uses the facility (other than as an argument passed when the
+facility is invoked), then you may convey a copy of the modified
+version:
+
+ a) under this License, provided that you make a good faith effort to
+ ensure that, in the event an Application does not supply the
+ function or data, the facility still operates, and performs
+ whatever part of its purpose remains meaningful, or
+
+ b) under the GNU GPL, with none of the additional permissions of
+ this License applicable to that copy.
+
+ 3. Object Code Incorporating Material from Library Header Files.
+
+ The object code form of an Application may incorporate material from
+a header file that is part of the Library. You may convey such object
+code under terms of your choice, provided that, if the incorporated
+material is not limited to numerical parameters, data structure
+layouts and accessors, or small macros, inline functions and templates
+(ten or fewer lines in length), you do both of the following:
+
+ a) Give prominent notice with each copy of the object code that the
+ Library is used in it and that the Library and its use are
+ covered by this License.
+
+ b) Accompany the object code with a copy of the GNU GPL and this license
+ document.
+
+ 4. Combined Works.
+
+ You may convey a Combined Work under terms of your choice that,
+taken together, effectively do not restrict modification of the
+portions of the Library contained in the Combined Work and reverse
+engineering for debugging such modifications, if you also do each of
+the following:
+
+ a) Give prominent notice with each copy of the Combined Work that
+ the Library is used in it and that the Library and its use are
+ covered by this License.
+
+ b) Accompany the Combined Work with a copy of the GNU GPL and this license
+ document.
+
+ c) For a Combined Work that displays copyright notices during
+ execution, include the copyright notice for the Library among
+ these notices, as well as a reference directing the user to the
+ copies of the GNU GPL and this license document.
+
+ d) Do one of the following:
+
+ 0) Convey the Minimal Corresponding Source under the terms of this
+ License, and the Corresponding Application Code in a form
+ suitable for, and under terms that permit, the user to
+ recombine or relink the Application with a modified version of
+ the Linked Version to produce a modified Combined Work, in the
+ manner specified by section 6 of the GNU GPL for conveying
+ Corresponding Source.
+
+ 1) Use a suitable shared library mechanism for linking with the
+ Library. A suitable mechanism is one that (a) uses at run time
+ a copy of the Library already present on the user's computer
+ system, and (b) will operate properly with a modified version
+ of the Library that is interface-compatible with the Linked
+ Version.
+
+ e) Provide Installation Information, but only if you would otherwise
+ be required to provide such information under section 6 of the
+ GNU GPL, and only to the extent that such information is
+ necessary to install and execute a modified version of the
+ Combined Work produced by recombining or relinking the
+ Application with a modified version of the Linked Version. (If
+ you use option 4d0, the Installation Information must accompany
+ the Minimal Corresponding Source and Corresponding Application
+ Code. If you use option 4d1, you must provide the Installation
+ Information in the manner specified by section 6 of the GNU GPL
+ for conveying Corresponding Source.)
+
+ 5. Combined Libraries.
+
+ You may place library facilities that are a work based on the
+Library side by side in a single library together with other library
+facilities that are not Applications and are not covered by this
+License, and convey such a combined library under terms of your
+choice, if you do both of the following:
+
+ a) Accompany the combined library with a copy of the same work based
+ on the Library, uncombined with any other library facilities,
+ conveyed under the terms of this License.
+
+ b) Give prominent notice with the combined library that part of it
+ is a work based on the Library, and explaining where to find the
+ accompanying uncombined form of the same work.
+
+ 6. Revised Versions of the GNU Lesser General Public License.
+
+ The Free Software Foundation may publish revised and/or new versions
+of the GNU Lesser General Public License from time to time. Such new
+versions will be similar in spirit to the present version, but may
+differ in detail to address new problems or concerns.
+
+ Each version is given a distinguishing version number. If the
+Library as you received it specifies that a certain numbered version
+of the GNU Lesser General Public License "or any later version"
+applies to it, you have the option of following the terms and
+conditions either of that published version or of any later version
+published by the Free Software Foundation. If the Library as you
+received it does not specify a version number of the GNU Lesser
+General Public License, you may choose any version of the GNU Lesser
+General Public License ever published by the Free Software Foundation.
+
+ If the Library as you received it specifies that a proxy can decide
+whether future versions of the GNU Lesser General Public License shall
+apply, that proxy's public statement of acceptance of any version is
+permanent authorization for you to choose that version for the
+Library.
+
Modified: trunk/eugene-plantuml-templates/pom.xml
===================================================================
--- trunk/eugene-plantuml-templates/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene-plantuml-templates/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
@@ -23,7 +23,6 @@
#L%
-->
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
-
<modelVersion>4.0.0</modelVersion>
<parent>
@@ -35,6 +34,9 @@
<groupId>org.nuiton.eugene</groupId>
<artifactId>eugene-plantuml-templates</artifactId>
+ <name>EUGene :: PlantUML templates</name>
+ <inceptionYear>2013</inceptionYear>
+
<dependencies>
<dependency>
@@ -51,11 +53,4 @@
</dependencies>
- <name>EUGene :: PlantUML templates</name>
-
- <inceptionYear>2013</inceptionYear>
-
</project>
-
-
-
Added: trunk/eugene-plantuml-templates/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/eugene-plantuml-templates/src/license/THIRD-PARTY.properties (rev 0)
+++ trunk/eugene-plantuml-templates/src/license/THIRD-PARTY.properties 2013-07-23 14:45:53 UTC (rev 1290)
@@ -0,0 +1,22 @@
+# Generated by org.codehaus.mojo.license.AddThirdPartyMojo
+#-------------------------------------------------------------------------------
+# Already used licenses in project :
+# - BSD License
+# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
+# - Indiana University Extreme! Lab Software License, vesion 1.1.1
+# - Lesser General Public License (LGPL) v 3.0
+# - Lesser General Public License (LPGL)
+# - Lesser General Public License (LPGL) v 2.1
+# - MIT License
+# - Mozilla Public License Version 1.0
+# - The Apache Software License, Version 2.0
+# - The GNU General Public License
+# - The SAX License
+# - The W3C License
+# - http://jaxen.codehaus.org/license.html
+#-------------------------------------------------------------------------------
+# Please fill the missing licenses for dependencies :
+#
+#
+#Tue Jul 23 16:39:16 CEST 2013
+commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
Property changes on: trunk/eugene-plantuml-templates/src/license/THIRD-PARTY.properties
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/eugene-yaml-templates/LICENSE.txt
===================================================================
--- trunk/eugene-yaml-templates/LICENSE.txt 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene-yaml-templates/LICENSE.txt 2013-07-23 14:45:53 UTC (rev 1290)
@@ -0,0 +1,166 @@
+ GNU LESSER GENERAL PUBLIC LICENSE
+ Version 3, 29 June 2007
+
+ Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>
+ Everyone is permitted to copy and distribute verbatim copies
+ of this license document, but changing it is not allowed.
+
+
+ This version of the GNU Lesser General Public License incorporates
+the terms and conditions of version 3 of the GNU General Public
+License, supplemented by the additional permissions listed below.
+
+ 0. Additional Definitions.
+
+ As used herein, "this License" refers to version 3 of the GNU Lesser
+General Public License, and the "GNU GPL" refers to version 3 of the GNU
+General Public License.
+
+ "The Library" refers to a covered work governed by this License,
+other than an Application or a Combined Work as defined below.
+
+ An "Application" is any work that makes use of an interface provided
+by the Library, but which is not otherwise based on the Library.
+Defining a subclass of a class defined by the Library is deemed a mode
+of using an interface provided by the Library.
+
+ A "Combined Work" is a work produced by combining or linking an
+Application with the Library. The particular version of the Library
+with which the Combined Work was made is also called the "Linked
+Version".
+
+ The "Minimal Corresponding Source" for a Combined Work means the
+Corresponding Source for the Combined Work, excluding any source code
+for portions of the Combined Work that, considered in isolation, are
+based on the Application, and not on the Linked Version.
+
+ The "Corresponding Application Code" for a Combined Work means the
+object code and/or source code for the Application, including any data
+and utility programs needed for reproducing the Combined Work from the
+Application, but excluding the System Libraries of the Combined Work.
+
+ 1. Exception to Section 3 of the GNU GPL.
+
+ You may convey a covered work under sections 3 and 4 of this License
+without being bound by section 3 of the GNU GPL.
+
+ 2. Conveying Modified Versions.
+
+ If you modify a copy of the Library, and, in your modifications, a
+facility refers to a function or data to be supplied by an Application
+that uses the facility (other than as an argument passed when the
+facility is invoked), then you may convey a copy of the modified
+version:
+
+ a) under this License, provided that you make a good faith effort to
+ ensure that, in the event an Application does not supply the
+ function or data, the facility still operates, and performs
+ whatever part of its purpose remains meaningful, or
+
+ b) under the GNU GPL, with none of the additional permissions of
+ this License applicable to that copy.
+
+ 3. Object Code Incorporating Material from Library Header Files.
+
+ The object code form of an Application may incorporate material from
+a header file that is part of the Library. You may convey such object
+code under terms of your choice, provided that, if the incorporated
+material is not limited to numerical parameters, data structure
+layouts and accessors, or small macros, inline functions and templates
+(ten or fewer lines in length), you do both of the following:
+
+ a) Give prominent notice with each copy of the object code that the
+ Library is used in it and that the Library and its use are
+ covered by this License.
+
+ b) Accompany the object code with a copy of the GNU GPL and this license
+ document.
+
+ 4. Combined Works.
+
+ You may convey a Combined Work under terms of your choice that,
+taken together, effectively do not restrict modification of the
+portions of the Library contained in the Combined Work and reverse
+engineering for debugging such modifications, if you also do each of
+the following:
+
+ a) Give prominent notice with each copy of the Combined Work that
+ the Library is used in it and that the Library and its use are
+ covered by this License.
+
+ b) Accompany the Combined Work with a copy of the GNU GPL and this license
+ document.
+
+ c) For a Combined Work that displays copyright notices during
+ execution, include the copyright notice for the Library among
+ these notices, as well as a reference directing the user to the
+ copies of the GNU GPL and this license document.
+
+ d) Do one of the following:
+
+ 0) Convey the Minimal Corresponding Source under the terms of this
+ License, and the Corresponding Application Code in a form
+ suitable for, and under terms that permit, the user to
+ recombine or relink the Application with a modified version of
+ the Linked Version to produce a modified Combined Work, in the
+ manner specified by section 6 of the GNU GPL for conveying
+ Corresponding Source.
+
+ 1) Use a suitable shared library mechanism for linking with the
+ Library. A suitable mechanism is one that (a) uses at run time
+ a copy of the Library already present on the user's computer
+ system, and (b) will operate properly with a modified version
+ of the Library that is interface-compatible with the Linked
+ Version.
+
+ e) Provide Installation Information, but only if you would otherwise
+ be required to provide such information under section 6 of the
+ GNU GPL, and only to the extent that such information is
+ necessary to install and execute a modified version of the
+ Combined Work produced by recombining or relinking the
+ Application with a modified version of the Linked Version. (If
+ you use option 4d0, the Installation Information must accompany
+ the Minimal Corresponding Source and Corresponding Application
+ Code. If you use option 4d1, you must provide the Installation
+ Information in the manner specified by section 6 of the GNU GPL
+ for conveying Corresponding Source.)
+
+ 5. Combined Libraries.
+
+ You may place library facilities that are a work based on the
+Library side by side in a single library together with other library
+facilities that are not Applications and are not covered by this
+License, and convey such a combined library under terms of your
+choice, if you do both of the following:
+
+ a) Accompany the combined library with a copy of the same work based
+ on the Library, uncombined with any other library facilities,
+ conveyed under the terms of this License.
+
+ b) Give prominent notice with the combined library that part of it
+ is a work based on the Library, and explaining where to find the
+ accompanying uncombined form of the same work.
+
+ 6. Revised Versions of the GNU Lesser General Public License.
+
+ The Free Software Foundation may publish revised and/or new versions
+of the GNU Lesser General Public License from time to time. Such new
+versions will be similar in spirit to the present version, but may
+differ in detail to address new problems or concerns.
+
+ Each version is given a distinguishing version number. If the
+Library as you received it specifies that a certain numbered version
+of the GNU Lesser General Public License "or any later version"
+applies to it, you have the option of following the terms and
+conditions either of that published version or of any later version
+published by the Free Software Foundation. If the Library as you
+received it does not specify a version number of the GNU Lesser
+General Public License, you may choose any version of the GNU Lesser
+General Public License ever published by the Free Software Foundation.
+
+ If the Library as you received it specifies that a proxy can decide
+whether future versions of the GNU Lesser General Public License shall
+apply, that proxy's public statement of acceptance of any version is
+permanent authorization for you to choose that version for the
+Library.
+
Modified: trunk/eugene-yaml-templates/pom.xml
===================================================================
--- trunk/eugene-yaml-templates/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/eugene-yaml-templates/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
@@ -23,7 +23,6 @@
#L%
-->
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
-
<modelVersion>4.0.0</modelVersion>
<parent>
@@ -35,6 +34,9 @@
<groupId>org.nuiton.eugene</groupId>
<artifactId>eugene-yaml-templates</artifactId>
+ <name>EUGene :: YAML templates</name>
+ <inceptionYear>2013</inceptionYear>
+
<dependencies>
<dependency>
@@ -45,10 +47,6 @@
</dependencies>
- <name>EUGene :: YAML templates</name>
-
- <inceptionYear>2013</inceptionYear>
-
<build>
<plugins>
<!-- expose new plexus components -->
@@ -67,6 +65,3 @@
</build>
</project>
-
-
-
Added: trunk/eugene-yaml-templates/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/eugene-yaml-templates/src/license/THIRD-PARTY.properties (rev 0)
+++ trunk/eugene-yaml-templates/src/license/THIRD-PARTY.properties 2013-07-23 14:45:53 UTC (rev 1290)
@@ -0,0 +1,21 @@
+# Generated by org.codehaus.mojo.license.AddThirdPartyMojo
+#-------------------------------------------------------------------------------
+# Already used licenses in project :
+# - BSD License
+# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
+# - Indiana University Extreme! Lab Software License, vesion 1.1.1
+# - Lesser General Public License (LGPL) v 3.0
+# - Lesser General Public License (LPGL)
+# - Lesser General Public License (LPGL) v 2.1
+# - MIT License
+# - Mozilla Public License Version 1.0
+# - The Apache Software License, Version 2.0
+# - The SAX License
+# - The W3C License
+# - http://jaxen.codehaus.org/license.html
+#-------------------------------------------------------------------------------
+# Please fill the missing licenses for dependencies :
+#
+#
+#Tue Jul 23 16:39:16 CEST 2013
+commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
Property changes on: trunk/eugene-yaml-templates/src/license/THIRD-PARTY.properties
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
+++ trunk/pom.xml 2013-07-23 14:45:53 UTC (rev 1290)
@@ -23,10 +23,8 @@
#L%
-->
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
-
<modelVersion>4.0.0</modelVersion>
-
- <!-- ************************************************************* -->
+<!-- ************************************************************* -->
<!-- *** POM Relationships *************************************** -->
<!-- ************************************************************* -->
<parent>
@@ -36,8 +34,98 @@
</parent>
<artifactId>eugene</artifactId>
- <version>2.7-SNAPSHOT</version>
+ <version>2.7-SNAPSHOT</version><!-- ************************************************************* -->
+ <!-- *** Build Settings ****************************************** -->
+ <!-- ************************************************************* -->
+ <packaging>pom</packaging>
+<!-- ************************************************************* -->
+ <!-- *** Project Information ************************************* -->
+ <!-- ************************************************************* -->
+ <name>EUGene</name>
+ <description>Efficient Universal Generator</description>
+ <url>http://maven-site.nuiton.org/eugene</url>
+ <inceptionYear>2004</inceptionYear>
+<!-- Developers -->
+ <developers>
+ <developer>
+ <name>Benjamin Poussin</name>
+ <id>bpoussin</id>
+ <email>poussin at codelutin dot com</email>
+ <organization>CodeLutin</organization>
+ <organizationUrl>http://codelutin.com</organizationUrl>
+ <timezone>Europe/Paris</timezone>
+ <roles>
+ <role>developer</role>
+ <role>Debian packager</role>
+ </roles>
+ </developer>
+ <developer>
+ <name>Arnaud Thimel</name>
+ <id>athimel</id>
+ <email>thimel at codelutin dot com</email>
+ <organization>CodeLutin</organization>
+ <organizationUrl>http://codelutin.com</organizationUrl>
+ <timezone>Europe/Paris</timezone>
+ <roles>
+ <role>developer</role>
+ </roles>
+ </developer>
+
+ <developer>
+ <name>Julien Ruchaud</name>
+ <id>jruchaud</id>
+ <email>ruchaud at codelutin dot com</email>
+ <organization>CodeLutin</organization>
+ <organizationUrl>http://codelutin.com</organizationUrl>
+ <timezone>Europe/Paris</timezone>
+ <roles>
+ <role>developer</role>
+ </roles>
+ </developer>
+
+ <developer>
+ <name>Eric Chatellier</name>
+ <id>echatellier</id>
+ <email>chatellier at codelutin dot com</email>
+ <organization>CodeLutin</organization>
+ <organizationUrl>http://codelutin.com</organizationUrl>
+ <timezone>Europe/Paris</timezone>
+ <roles>
+ <role>developer</role>
+ </roles>
+ </developer>
+
+ <developer>
+ <name>Tony Chemit</name>
+ <id>tchemit</id>
+ <email>chemit at codelutin dot com</email>
+ <organization>CodeLutin</organization>
+ <organizationUrl>http://codelutin.com</organizationUrl>
+ <timezone>Europe/Paris</timezone>
+ <roles>
+ <role>developer</role>
+ </roles>
+ </developer>
+
+ <developer>
+ <name>Florian Desbois</name>
+ <id>fdesbois</id>
+ <roles>
+ <role>developer</role>
+ </roles>
+ </developer>
+ </developers>
+ <contributors>
+ <contributor>
+ <name>Stéphane Chorlet</name>
+ <timezone>Europe/Paris</timezone>
+ <roles>
+ <role>developer</role>
+ </roles>
+ </contributor>
+ </contributors>
+
<modules>
<module>eugene</module>
<module>eugene-java-templates</module>
@@ -45,7 +133,42 @@
<module>eugene-maven-plugin</module>
<module>eugene-yaml-templates</module>
</modules>
+<!-- ************************************************************* -->
+ <!-- *** Build Environment ************************************** -->
+ <!-- ************************************************************* -->
+ <!-- Source control management. -->
+ <scm>
+ <connection>scm:svn:http://svn.nuiton.org/svn/eugene/trunk</connection>
+ <developerConnection>
+ scm:svn:http://svn.nuiton.org/svn/eugene/trunk
+ </developerConnection>
+ <url>http://nuiton.org/projects/eugene/repository/show/trunk</url>
+ </scm>
+ <distributionManagement>
+ <site>
+ <id>${platform}</id>
+ <url>${our.site.repository}/${projectId}</url>
+ </site>
+ </distributionManagement>
+
+ <properties>
+ <!-- pour un muli module on doit fixer le projectId -->
+ <projectId>eugene</projectId>
+
+ <processorPluginVersion>1.3</processorPluginVersion>
+ <nuitonUtilsVersion>2.6.5</nuitonUtilsVersion>
+ <nuitonI18nVersion>2.5</nuitonI18nVersion>
+
+ <!--Multilanguage maven-site -->
+ <locales>en,fr</locales>
+
+ <!-- do not relativize links in generated site -->
+ <relativizeDecorationLinks>false</relativizeDecorationLinks>
+
+ <plexusPluginVersion>1.3.8</plexusPluginVersion>
+ </properties>
+
<dependencyManagement>
<dependencies>
@@ -216,129 +339,7 @@
</dependencies>
</dependencyManagement>
- <!-- ************************************************************* -->
- <!-- *** Project Information ************************************* -->
- <!-- ************************************************************* -->
- <name>EUGene</name>
- <description>Efficient Universal Generator</description>
- <inceptionYear>2004</inceptionYear>
- <url>http://maven-site.nuiton.org/eugene</url>
-
- <!-- Developers -->
- <developers>
- <developer>
- <name>Benjamin Poussin</name>
- <id>bpoussin</id>
- <email>poussin at codelutin dot com</email>
- <organization>CodeLutin</organization>
- <organizationUrl>http://codelutin.com</organizationUrl>
- <timezone>Europe/Paris</timezone>
- <roles>
- <role>developer</role>
- <role>Debian packager</role>
- </roles>
- </developer>
-
- <developer>
- <name>Arnaud Thimel</name>
- <id>athimel</id>
- <email>thimel at codelutin dot com</email>
- <organization>CodeLutin</organization>
- <organizationUrl>http://codelutin.com</organizationUrl>
- <timezone>Europe/Paris</timezone>
- <roles>
- <role>developer</role>
- </roles>
- </developer>
-
- <developer>
- <name>Julien Ruchaud</name>
- <id>jruchaud</id>
- <email>ruchaud at codelutin dot com</email>
- <organization>CodeLutin</organization>
- <organizationUrl>http://codelutin.com</organizationUrl>
- <timezone>Europe/Paris</timezone>
- <roles>
- <role>developer</role>
- </roles>
- </developer>
-
- <developer>
- <name>Eric Chatellier</name>
- <id>echatellier</id>
- <email>chatellier at codelutin dot com</email>
- <organization>CodeLutin</organization>
- <organizationUrl>http://codelutin.com</organizationUrl>
- <timezone>Europe/Paris</timezone>
- <roles>
- <role>developer</role>
- </roles>
- </developer>
-
- <developer>
- <name>Tony Chemit</name>
- <id>tchemit</id>
- <email>chemit at codelutin dot com</email>
- <organization>CodeLutin</organization>
- <organizationUrl>http://codelutin.com</organizationUrl>
- <timezone>Europe/Paris</timezone>
- <roles>
- <role>developer</role>
- </roles>
- </developer>
-
- <developer>
- <name>Florian Desbois</name>
- <id>fdesbois</id>
- <roles>
- <role>developer</role>
- </roles>
- </developer>
- </developers>
-
- <contributors>
- <contributor>
- <name>Stéphane Chorlet</name>
- <timezone>Europe/Paris</timezone>
- <roles>
- <role>developer</role>
- </roles>
- </contributor>
- </contributors>
-
- <!-- ************************************************************* -->
- <!-- *** Build Settings ****************************************** -->
- <!-- ************************************************************* -->
-
- <packaging>pom</packaging>
-
- <properties>
- <!-- pour un muli module on doit fixer le projectId -->
- <projectId>eugene</projectId>
-
- <processorPluginVersion>1.3</processorPluginVersion>
- <nuitonUtilsVersion>2.6.5</nuitonUtilsVersion>
- <nuitonI18nVersion>2.5</nuitonI18nVersion>
-
- <!--Multilanguage maven-site -->
- <locales>en,fr</locales>
-
- <!-- do not relativize links in generated site -->
- <relativizeDecorationLinks>false</relativizeDecorationLinks>
-
- <plexusPluginVersion>1.3.8</plexusPluginVersion>
- </properties>
-
<build>
-
- <extensions>
- <extension>
- <groupId>org.apache.maven.wagon</groupId>
- <artifactId>wagon-ssh-external</artifactId>
- <version>1.0</version>
- </extension>
-
- </extensions>
<pluginManagement>
<plugins>
@@ -373,33 +374,20 @@
</plugins>
</pluginManagement>
+ <extensions>
+ <extension>
+ <groupId>org.apache.maven.wagon</groupId>
+ <artifactId>wagon-ssh-external</artifactId>
+ <version>1.0</version>
+ </extension>
+ </extensions>
</build>
<reporting>
<excludeDefaults>true</excludeDefaults>
</reporting>
- <!-- ************************************************************* -->
- <!-- *** Build Environment ************************************** -->
- <!-- ************************************************************* -->
-
- <!-- Source control management. -->
- <scm>
- <connection>scm:svn:http://svn.nuiton.org/svn/eugene/trunk</connection>
- <developerConnection>
- scm:svn:http://svn.nuiton.org/svn/eugene/trunk
- </developerConnection>
- <url>http://nuiton.org/projects/eugene/repository/show/trunk</url>
- </scm>
-
- <distributionManagement>
- <site>
- <id>${platform}</id>
- <url>${our.site.repository}/${projectId}</url>
- </site>
- </distributionManagement>
-
<profiles>
<profile>
<id>reporting</id>
1
0
r1289 - in trunk: . eugene eugene-java-templates eugene-maven-plugin eugene-plantuml-templates eugene-yaml-templates
by tchemit@users.nuiton.org 23 Jul '13
by tchemit@users.nuiton.org 23 Jul '13
23 Jul '13
Author: tchemit
Date: 2013-07-23 16:41:37 +0200 (Tue, 23 Jul 2013)
New Revision: 1289
Url: http://nuiton.org/projects/eugene/repository/revisions/1289
Log:
prepare version 2.7
Modified:
trunk/eugene-java-templates/pom.xml
trunk/eugene-maven-plugin/pom.xml
trunk/eugene-plantuml-templates/pom.xml
trunk/eugene-yaml-templates/pom.xml
trunk/eugene/pom.xml
trunk/pom.xml
Modified: trunk/eugene/pom.xml
===================================================================
--- trunk/eugene/pom.xml 2013-07-19 16:03:15 UTC (rev 1288)
+++ trunk/eugene/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
@@ -32,7 +32,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.6.4-SNAPSHOT</version>
+ <version>2.7-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-java-templates/pom.xml
===================================================================
--- trunk/eugene-java-templates/pom.xml 2013-07-19 16:03:15 UTC (rev 1288)
+++ trunk/eugene-java-templates/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
@@ -29,7 +29,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.6.4-SNAPSHOT</version>
+ <version>2.7-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-maven-plugin/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/pom.xml 2013-07-19 16:03:15 UTC (rev 1288)
+++ trunk/eugene-maven-plugin/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
@@ -33,7 +33,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.6.4-SNAPSHOT</version>
+ <version>2.7-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-plantuml-templates/pom.xml
===================================================================
--- trunk/eugene-plantuml-templates/pom.xml 2013-07-19 16:03:15 UTC (rev 1288)
+++ trunk/eugene-plantuml-templates/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
@@ -29,7 +29,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.6.4-SNAPSHOT</version>
+ <version>2.7-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/eugene-yaml-templates/pom.xml
===================================================================
--- trunk/eugene-yaml-templates/pom.xml 2013-07-19 16:03:15 UTC (rev 1288)
+++ trunk/eugene-yaml-templates/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
@@ -29,7 +29,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>eugene</artifactId>
- <version>2.6.4-SNAPSHOT</version>
+ <version>2.7-SNAPSHOT</version>
</parent>
<groupId>org.nuiton.eugene</groupId>
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2013-07-19 16:03:15 UTC (rev 1288)
+++ trunk/pom.xml 2013-07-23 14:41:37 UTC (rev 1289)
@@ -36,7 +36,7 @@
</parent>
<artifactId>eugene</artifactId>
- <version>2.6.4-SNAPSHOT</version>
+ <version>2.7-SNAPSHOT</version>
<modules>
<module>eugene</module>
1
0
Author: dcosse
Date: 2013-07-19 18:03:15 +0200 (Fri, 19 Jul 2013)
New Revision: 1288
Url: http://nuiton.org/projects/eugene/repository/revisions/1288
Log:
correction de la documentation
Modified:
trunk/src/site/fr/rst/05-execution.rst.vm
trunk/src/site/fr/rst/index.rst
trunk/src/site/rst/05-execution.rst.vm
trunk/src/site/site_en.xml
trunk/src/site/site_fr.xml
Modified: trunk/src/site/fr/rst/05-execution.rst.vm
===================================================================
--- trunk/src/site/fr/rst/05-execution.rst.vm 2013-07-11 14:17:37 UTC (rev 1287)
+++ trunk/src/site/fr/rst/05-execution.rst.vm 2013-07-19 16:03:15 UTC (rev 1288)
@@ -39,7 +39,7 @@
---
Ce module est désactivité depuis la version 2.5.
-::Consultez la documentation dans le `module ant`_.
+Consultez la documentation dans le `module ant`_.
Maven
-----
@@ -61,5 +61,8 @@
pouvoir générer des fichiers en utilisant le plugin maven. Voir `les exemples
et la documentation du plugin`_ .
+.. _module ant: ../ant-eugene-task/fr/
+
.. _les exemples et la documentation du plugin: ../eugene-maven-plugin/fr/example.html
-::.. _module ant: ../ant-eugene-task/fr/
+
+
Modified: trunk/src/site/fr/rst/index.rst
===================================================================
--- trunk/src/site/fr/rst/index.rst 2013-07-11 14:17:37 UTC (rev 1287)
+++ trunk/src/site/fr/rst/index.rst 2013-07-19 16:03:15 UTC (rev 1288)
@@ -61,9 +61,9 @@
.. _eugene-api: ../eugene/fr/index.html
.. _eugene-java-templates: ../eugene-java-templates/fr/index.html
+.. _eugene-maven-plugin: eugene-maven-plugin/fr/index.html
.. _eugene-plantuml-templates: ../eugene-plantuml-templates/fr/index.html
-.. _eugene-ymal-templates: ../eugene-plantuml-templates/fr/index.html
-.. _eugene-maven-plugin: ../eugene-yaml-templates/fr/index.html
+.. _eugene-yaml-templates: ../eugene-yaml-templates/fr/index.html
Plus d'infos sur le projet sur la `forge nuiton`_ .
Modified: trunk/src/site/rst/05-execution.rst.vm
===================================================================
--- trunk/src/site/rst/05-execution.rst.vm 2013-07-11 14:17:37 UTC (rev 1287)
+++ trunk/src/site/rst/05-execution.rst.vm 2013-07-19 16:03:15 UTC (rev 1288)
@@ -39,9 +39,8 @@
---
This module was removed since version 2.5.
+See documentation in `ant module`_.
-::See documentation in `ant module`_.
-
Maven
-----
@@ -60,5 +59,7 @@
You can now extends wanted Transformer and Generator to be able to generate
files using the maven plugin. See `plugin documentation and examples`_ .
+.. _ant module: ant-eugene-task/
+
.. _plugin documentation and examples: eugene-maven-plugin/example.html
-::.. _ant module: ant-eugene-task/
+
Modified: trunk/src/site/site_en.xml
===================================================================
--- trunk/src/site/site_en.xml 2013-07-11 14:17:37 UTC (rev 1287)
+++ trunk/src/site/site_en.xml 2013-07-19 16:03:15 UTC (rev 1288)
@@ -98,7 +98,7 @@
</menu>
<menu name="Project">
- <item name="Home" href="http://nuiton.org/projects/show/eugene"/>
+ <item name="Home" href="http://nuiton.org/projects/eugene"/>
<item name="Download" href="http://nuiton.org/projects/eugene/files"/>
<item name="Trackers" href="http://nuiton.org/projects/eugene/issues"/>
</menu>
Modified: trunk/src/site/site_fr.xml
===================================================================
--- trunk/src/site/site_fr.xml 2013-07-11 14:17:37 UTC (rev 1287)
+++ trunk/src/site/site_fr.xml 2013-07-19 16:03:15 UTC (rev 1288)
@@ -98,7 +98,7 @@
</menu>
<menu name="Projet">
- <item name="Accueil" href="http://nuiton.org/projects/show/eugene"/>
+ <item name="Accueil" href="http://nuiton.org/projects/eugene"/>
<item name="Téléchargement"
href="http://nuiton.org/projects/eugene/files"/>
<item name="Trackers" href="http://nuiton.org/projects/eugene/issues"/>
1
0
r1287 - in trunk/eugene/src/main/java/org/nuiton/eugene/java: . extension
by tchemit@users.nuiton.org 11 Jul '13
by tchemit@users.nuiton.org 11 Jul '13
11 Jul '13
Author: tchemit
Date: 2013-07-11 16:17:37 +0200 (Thu, 11 Jul 2013)
New Revision: 1287
Url: http://nuiton.org/projects/eugene/repository/revisions/1287
Log:
fixes #2738: Improve api to add annotations (improve doc)
Modified:
trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/ObjectModelTransformerToJava.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java 2013-07-11 13:53:23 UTC (rev 1286)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java 2013-07-11 14:17:37 UTC (rev 1287)
@@ -297,24 +297,23 @@
/**
* Add an annotation on an element of a classifier.
*
- * @param classifier where the annotation will be added.
- * @param element element on which add annotation
+ * @param classifier where the annotation will be added.
+ * @param element element on which add annotation
* @param annotationType type of annotation to add
* @return the instanciated annotation
*/
public ObjectModelAnnotation addAnnotation(ObjectModelClassifier classifier,
- ObjectModelElement element,
- String annotationType) {
+ ObjectModelElement element,
+ String annotationType) {
Preconditions.checkNotNull("Can't add a null annotation");
- Preconditions.checkArgument(SourceVersion.isName(annotationType),"Annotation type must be a valid type , but was: "+annotationType);
-// if (annotation == null) {
-// return;
-// }
+ Preconditions.checkArgument(
+ SourceVersion.isName(annotationType),
+ "Annotation type must be a valid type , but was: " + annotationType);
AnnotationsManager manager =
annotationsManagerExtension.getManager(classifier);
-// annotation = annotation.trim();
- ObjectModelAnnotation annotation = new ObjectModelAnnotation(annotationType);
+ ObjectModelAnnotation annotation =
+ new ObjectModelAnnotation(annotationType);
manager.addAnnotation(element, annotation);
if (log.isDebugEnabled()) {
log.debug("Add annotation for <" + classifier.getQualifiedName() +
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/ObjectModelTransformerToJava.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/ObjectModelTransformerToJava.java 2013-07-11 13:53:23 UTC (rev 1286)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/ObjectModelTransformerToJava.java 2013-07-11 14:17:37 UTC (rev 1287)
@@ -425,12 +425,17 @@
/**
* Add an annotation of the given {@code element} of the given {@code classifier}.
- *
+ * <p/>
+ * <strong>Important note:</strong>
+ * <pre>
+ * Since 2.6.4, the behaviour of this method has changed, we only allowed
+ * now to pass here a annotation type and no longer a annotation
+ * string representation with some parameters...
+ * </pre>
* @param classifier holder of element to treat
* @param element where to add the annotation
* @param annotationType type of annotation to create
* @return the instanciated annotation
- * @since 2.6.4
*/
public ObjectModelAnnotation addAnnotation(ObjectModelClassifier classifier,
ObjectModelElement element,
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java 2013-07-11 13:53:23 UTC (rev 1286)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java 2013-07-11 14:17:37 UTC (rev 1287)
@@ -47,7 +47,6 @@
return type;
}
-
public List<ObjectModelAnnotationParameter> getParameters() {
return parameters;
}
1
0
r1286 - in trunk: eugene/src/main/java/org/nuiton/eugene/java eugene/src/main/java/org/nuiton/eugene/java/extension eugene-java-templates/src/main/java/org/nuiton/eugene/java
by tchemit@users.nuiton.org 11 Jul '13
by tchemit@users.nuiton.org 11 Jul '13
11 Jul '13
Author: tchemit
Date: 2013-07-11 15:53:23 +0200 (Thu, 11 Jul 2013)
New Revision: 1286
Url: http://nuiton.org/projects/eugene/repository/revisions/1286
Log:
fixes #2738: Improve api to add annotations
Added:
trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotationParameter.java
Modified:
trunk/eugene-java-templates/src/main/java/org/nuiton/eugene/java/SimpleJavaBeanTransformer.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaGenerator.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/ObjectModelTransformerToJava.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/AnnotationsManager.java
trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/AnnotationsManagerExtension.java
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaGenerator.java 2013-07-11 13:50:16 UTC (rev 1285)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaGenerator.java 2013-07-11 13:53:23 UTC (rev 1286)
@@ -25,6 +25,8 @@
package org.nuiton.eugene.java;
+import com.google.common.base.Joiner;
+import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
@@ -32,6 +34,8 @@
import org.nuiton.eugene.GeneratorUtil;
import org.nuiton.eugene.java.extension.AnnotationsManagerExtension;
import org.nuiton.eugene.java.extension.ImportsManagerExtension;
+import org.nuiton.eugene.java.extension.ObjectModelAnnotation;
+import org.nuiton.eugene.java.extension.ObjectModelAnnotationParameter;
import org.nuiton.eugene.models.object.ObjectModelAttribute;
import org.nuiton.eugene.models.object.ObjectModelClass;
import org.nuiton.eugene.models.object.ObjectModelClassifier;
@@ -222,17 +226,44 @@
AnnotationsManagerExtension managers = getModel().getExtension(
AnnotationsManagerExtension.OBJECTMODEL_EXTENSION,
AnnotationsManagerExtension.class);
- String[] annotations = managers.getAnnotations(clazz,element);
- for (String annotation : annotations) {
- if (!annotation.trim().startsWith("@")) {
- // add @ prefix
- annotation = "@" + annotation.trim();
+ List<ObjectModelAnnotation> annotations =
+ managers.getAnnotations(clazz, element);
+ for (ObjectModelAnnotation annotation : annotations) {
+// if (!annotation.trim().startsWith("@")) {
+// // add @ prefix
+// annotation = "@" + annotation.trim();
+// }
+ StringBuilder annotationBuilder= new StringBuilder("@"+annotation.getType());
+ List<ObjectModelAnnotationParameter> annotationParameters = annotation.getParameters();
+ if (CollectionUtils.isNotEmpty(annotationParameters)) {
+ annotationBuilder.append('(');
+ List<String> params = Lists.newArrayList();
+ for (ObjectModelAnnotationParameter annotationParameter : annotationParameters) {
+ String paramStr = annotationParameter.getName()+" = ";
+ Object value = annotationParameter.getValue();
+ if (value instanceof String) {
+ paramStr+="\""+value+"\"";
+ } else if (value instanceof Enum) {
+ Enum anEnum = (Enum) value;
+
+ paramStr += anEnum.getClass().getSimpleName() + "." + value;
+ }
+ else {
+ paramStr+= value.toString();
+ }
+ params.add(paramStr);
+ }
+ Joiner.on(", ").appendTo(annotationBuilder, params);
+
+ annotationBuilder.append(')');
}
+ String annotationStr =annotationBuilder.toString();
+
if (element instanceof ObjectModelOperation || element instanceof ObjectModelAttribute) {
/*{<%=prefix%>}*/
- annotation = " "+annotation;
+ annotationStr = " "+annotationStr;
}
-/*{<%=annotation%>}*/
+/*{<%=annotationStr%>}*/
if (element instanceof ObjectModelClassifier || element instanceof ObjectModelOperation || element instanceof ObjectModelAttribute) {
/*{
}*/
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/ObjectModelTransformerToJava.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/ObjectModelTransformerToJava.java 2013-07-11 13:50:16 UTC (rev 1285)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/ObjectModelTransformerToJava.java 2013-07-11 13:53:23 UTC (rev 1286)
@@ -32,6 +32,7 @@
import org.nuiton.eugene.EugeneTagValues;
import org.nuiton.eugene.GeneratorUtil;
import org.nuiton.eugene.Template;
+import org.nuiton.eugene.java.extension.ObjectModelAnnotation;
import org.nuiton.eugene.java.extension.ImportsManager;
import org.nuiton.eugene.models.object.ObjectModel;
import org.nuiton.eugene.models.object.ObjectModelAttribute;
@@ -122,18 +123,16 @@
* Add the {@link Generated} annotation to the given {@link ObjectModelClassifier}
*
* @param element the element to be generated on which the annotation will be added
+ * @since 2.7
*/
// TODO AThimel 06/07/13 Maybe be skipped by configuration ?
protected void addGeneratedAnnotation(ObjectModelClassifier element) {
- addImport(element, Generated.class);
- // TODO AThimel 08/07/13 Fix syntax as soon as it is possible to use annotations with parameters : http://www.nuiton.org/issues/2738
- String annotationName = Generated.class.getSimpleName();
String generatorName = getClass().getName();
Date now = new Date();
- String annotationText = String.format("%s(value = \"%s\", date = \"%s\")", annotationName, generatorName, now);
-
- addAnnotation(element, element, annotationText);
+ ObjectModelAnnotation annotation = addAnnotation(element, element, Generated.class);
+ addAnnotationParameter(element, annotation, "value", generatorName);
+ addAnnotationParameter(element, annotation, "date", now.toString());
}
protected ObjectModelClass createClass(String name, String packageName) {
@@ -424,13 +423,64 @@
builder.addComment(element, comment);
}
- public void addAnnotation(ObjectModelClassifier classifier,
- ObjectModelElement element,
- String annotation) {
- builder.addAnnotation(classifier, element, annotation);
+ /**
+ * Add an annotation of the given {@code element} of the given {@code classifier}.
+ *
+ * @param classifier holder of element to treat
+ * @param element where to add the annotation
+ * @param annotationType type of annotation to create
+ * @return the instanciated annotation
+ * @since 2.6.4
+ */
+ public ObjectModelAnnotation addAnnotation(ObjectModelClassifier classifier,
+ ObjectModelElement element,
+ String annotationType) {
+ return builder.addAnnotation(classifier, element, annotationType);
}
/**
+ * Add an annotation of the given {@code element} of the given {@code classifier}.
+ *
+ * @param classifier holder of element to treat
+ * @param element where to add the annotation
+ * @param annotationType type of annotation to create
+ * @return the instanciated annotation
+ * @since 2.6.4
+ */
+ public ObjectModelAnnotation addAnnotation(ObjectModelClassifier classifier,
+ ObjectModelElement element,
+ Class<?> annotationType) {
+ addImport(classifier, annotationType);
+ return builder.addAnnotation(classifier,
+ element,
+ annotationType.getSimpleName());
+ }
+
+ /**
+ * Add a parameter to an annotation.
+ *
+ *
+ * @param classifier
+ * @param annotation where to add the parameter
+ * @param annotationName parameter name
+ * @param annotationValue paramter value
+ * @return the annotation
+ * @since 2.6.4
+ */
+ public ObjectModelAnnotation addAnnotationParameter(ObjectModelClassifier classifier,
+ ObjectModelAnnotation annotation,
+ String annotationName,
+ Object annotationValue) {
+ if (annotationValue instanceof Enum) {
+ Enum value = (Enum) annotationValue;
+ addImport(classifier, value.getClass());
+ }
+ return builder.addAnnotationParameter(annotation,
+ annotationName,
+ annotationValue);
+ }
+
+ /**
* add an operation to the classifier with the form of a simple block
* of code.
* <p/>
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/AnnotationsManager.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/AnnotationsManager.java 2013-07-11 13:50:16 UTC (rev 1285)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/AnnotationsManager.java 2013-07-11 13:53:23 UTC (rev 1286)
@@ -28,6 +28,7 @@
import org.nuiton.eugene.models.object.ObjectModelElement;
import java.util.ArrayList;
+import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
@@ -43,9 +44,9 @@
*/
public class AnnotationsManager {
- private static final String[] EMPTY_STRING_ARRAY = new String[]{};
+// private static final String[] EMPTY_STRING_ARRAY = new String[]{};
- protected Map<ObjectModelElement, List<String>> annotations;
+ protected Map<ObjectModelElement, List<ObjectModelAnnotation>> annotations;
/**
* Add the {@code annotation} for the given {@code element} of
@@ -54,11 +55,12 @@
* @param element the element where to register the annotation
* @param annotation the annotation to register
*/
- public void addAnnotation(ObjectModelElement element, String annotation) {
- Map<ObjectModelElement, List<String>> map = getAnnotations();
- List<String> list = map.get(element);
+ public void addAnnotation(ObjectModelElement element,
+ ObjectModelAnnotation annotation) {
+ Map<ObjectModelElement, List<ObjectModelAnnotation>> map = getAnnotations();
+ List<ObjectModelAnnotation> list = map.get(element);
if (list == null) {
- list = new ArrayList<String>();
+ list = new ArrayList<ObjectModelAnnotation>();
map.put(element, list);
}
list.add(annotation);
@@ -71,16 +73,15 @@
* @param element the element where to search for annotations
* @return the annotations for the element (empty arry if none found
*/
- public String[] getAnnotations(ObjectModelElement element) {
- Map<ObjectModelElement, List<String>> map = getAnnotations();
- List<String> list = map.get(element);
- return list == null ? EMPTY_STRING_ARRAY :
- list.toArray(new String[list.size()]);
+ public List<ObjectModelAnnotation> getAnnotations(ObjectModelElement element) {
+ Map<ObjectModelElement, List<ObjectModelAnnotation>> map = getAnnotations();
+ List<ObjectModelAnnotation> list = map.get(element);
+ return list == null ? Collections.<ObjectModelAnnotation>emptyList() : list;
}
- protected Map<ObjectModelElement, List<String>> getAnnotations() {
+ protected Map<ObjectModelElement, List<ObjectModelAnnotation>> getAnnotations() {
if (annotations == null) {
- annotations = new HashMap<ObjectModelElement, List<String>>();
+ annotations = new HashMap<ObjectModelElement, List<ObjectModelAnnotation>>();
}
return annotations;
}
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/AnnotationsManagerExtension.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java (rev 0)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java 2013-07-11 13:53:23 UTC (rev 1286)
@@ -0,0 +1,76 @@
+package org.nuiton.eugene.java.extension;
+
+/*
+ * #%L
+ * EUGene :: EUGene
+ * $Id$
+ * $HeadURL$
+ * %%
+ * Copyright (C) 2004 - 2013 CodeLutin
+ * %%
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Lesser Public License for more details.
+ *
+ * You should have received a copy of the GNU General Lesser Public
+ * License along with this program. If not, see
+ * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ * #L%
+ */
+
+import java.util.ArrayList;
+import java.util.List;
+
+/**
+ * Define a annotation.
+ *
+ * @author tchemit <chemit(a)codelutin.com>
+ * @since 2.6.4
+ */
+public class ObjectModelAnnotation {
+
+ protected final String type;
+
+ protected List<ObjectModelAnnotationParameter> parameters;
+
+ public ObjectModelAnnotation(String type) {
+ this.type = type;
+ }
+
+ public String getType() {
+ return type;
+ }
+
+
+ public List<ObjectModelAnnotationParameter> getParameters() {
+ return parameters;
+ }
+
+ public void addParameter(ObjectModelAnnotationParameter parameter) {
+ if (parameters == null) {
+ parameters = new ArrayList<ObjectModelAnnotationParameter>();
+ }
+ parameters.add(parameter);
+ }
+
+ @Override
+ public boolean equals(Object o) {
+ if (this == o) return true;
+ if (!(o instanceof ObjectModelAnnotation)) return false;
+
+ ObjectModelAnnotation that = (ObjectModelAnnotation) o;
+
+ return type.equals(that.type);
+ }
+
+ @Override
+ public int hashCode() {
+ return type.hashCode();
+ }
+}
Property changes on: trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Added: trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotationParameter.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotationParameter.java (rev 0)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotationParameter.java 2013-07-11 13:53:23 UTC (rev 1286)
@@ -0,0 +1,52 @@
+package org.nuiton.eugene.java.extension;
+
+/*
+ * #%L
+ * EUGene :: EUGene
+ * $Id$
+ * $HeadURL$
+ * %%
+ * Copyright (C) 2004 - 2013 CodeLutin
+ * %%
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Lesser Public License for more details.
+ *
+ * You should have received a copy of the GNU General Lesser Public
+ * License along with this program. If not, see
+ * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ * #L%
+ */
+
+/**
+ * Defines a annotation parameter.
+ *
+ * @author tchemit <chemit(a)codelutin.com>
+ * @since 2.6.4
+ */
+public class ObjectModelAnnotationParameter {
+
+ protected final String name;
+
+ protected final Object value;
+
+ public ObjectModelAnnotationParameter(String name, Object value) {
+ this.name = name;
+ this.value = value;
+ }
+
+ public String getName() {
+ return name;
+ }
+
+ public Object getValue() {
+ return value;
+ }
+
+}
Property changes on: trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotationParameter.java
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/eugene-java-templates/src/main/java/org/nuiton/eugene/java/SimpleJavaBeanTransformer.java
===================================================================
--- trunk/eugene-java-templates/src/main/java/org/nuiton/eugene/java/SimpleJavaBeanTransformer.java 2013-07-11 13:50:16 UTC (rev 1285)
+++ trunk/eugene-java-templates/src/main/java/org/nuiton/eugene/java/SimpleJavaBeanTransformer.java 2013-07-11 13:53:23 UTC (rev 1286)
@@ -104,7 +104,7 @@
for (ObjectModelOperation operation : getPublicOperations(outputClass)) {
addAnnotation(outputClass,
operation,
- Override.class.getSimpleName());
+ Override.class);
}
}
1
0
Author: tchemit
Date: 2013-07-11 15:50:16 +0200 (Thu, 11 Jul 2013)
New Revision: 1285
Url: http://nuiton.org/projects/eugene/repository/revisions/1285
Log:
fix some docs
Modified:
trunk/src/site/fr/rst/index.rst
trunk/src/site/rst/08-FAQ.rst
trunk/src/site/rst/index.rst
Modified: trunk/src/site/fr/rst/index.rst
===================================================================
--- trunk/src/site/fr/rst/index.rst 2013-07-11 13:50:00 UTC (rev 1284)
+++ trunk/src/site/fr/rst/index.rst 2013-07-11 13:50:16 UTC (rev 1285)
@@ -51,17 +51,19 @@
.. _Generator: 07-glossaire.html
.. _FAQ: 08-FAQ.html
-Le projet EUGene est composé de 3 modules :
+Le projet EUGene est composé de 5 modules :
* `eugene-api`_ (Api de base d'EUGene)
* `eugene-java-templates`_ (Templates pour générer des classes java)
- * `eugene-plantuml-templates`_ (depuis la version 2.7) (Templates pour générer des diagrammes plantumlclasses java)
+ * `eugene-plantuml-templates`_ (depuis la version 2.7) (Templates pour générer des diagrammes plantumlclasses java)
+ * `eugene-yaml-templates`_ (depuis la version 2.7) (Pour lire un object model depuis des fichiers yaml)
* `eugene-maven-plugin`_ (Plugin maven pour lancer des générations)
.. _eugene-api: ../eugene/fr/index.html
.. _eugene-java-templates: ../eugene-java-templates/fr/index.html
-.. _eugene-maven-plugin: ../eugene-maven-plugin/fr/index.html
.. _eugene-plantuml-templates: ../eugene-plantuml-templates/fr/index.html
+.. _eugene-ymal-templates: ../eugene-plantuml-templates/fr/index.html
+.. _eugene-maven-plugin: ../eugene-yaml-templates/fr/index.html
Plus d'infos sur le projet sur la `forge nuiton`_ .
Modified: trunk/src/site/rst/08-FAQ.rst
===================================================================
--- trunk/src/site/rst/08-FAQ.rst 2013-07-11 13:50:00 UTC (rev 1284)
+++ trunk/src/site/rst/08-FAQ.rst 2013-07-11 13:50:16 UTC (rev 1285)
@@ -27,7 +27,7 @@
FAQ
===
-How to convert UML models from Poseidon to AgroUML ?
+How to convert UML models from Poseidon to ArgoUML ?
====================================================
You have to save your model using Poseidon in XMI, or extract it from the .zuml
Modified: trunk/src/site/rst/index.rst
===================================================================
--- trunk/src/site/rst/index.rst 2013-07-11 13:50:00 UTC (rev 1284)
+++ trunk/src/site/rst/index.rst 2013-07-11 13:50:16 UTC (rev 1285)
@@ -51,17 +51,19 @@
.. _Generator: 07-glossaire.html
.. _FAQ: 08-FAQ.html
-EUGene is divided into 4 modules :
+EUGene is divided into 5 modules :
* `eugene-api`_ (EUGene Api)
- * `eugene-java-templates`_ (Templates pour générer des classes java)
- * `eugene-plantuml-templates`_ (depuis la version 2.7) (Templates pour générer des diagrammes plantumlclasses java)
+ * `eugene-java-templates`_ (Templates to generate java stuff)
+ * `eugene-plantuml-templates`_ (since version 2.7) (Templates to generate plantuml from an object model)
+ * `eugene-yaml-templates`_ (since version 2.7) (Templates to model object model from yaml files)
* `eugene-maven-plugin`_ (Maven Plugin to generate stuff using EUGene)
.. _eugene-api: eugene/index.html
.. _eugene-java-templates: ../eugene-java-templates/fr/index.html
.. _eugene-maven-plugin: eugene-maven-plugin/index.html
.. _eugene-plantuml-templates: ../eugene-plantuml-templates/index.html
+.. _eugene-yaml-templates: ../eugene-yaml-templates/index.html
More info on the project on `nuiton's forge`_ .
1
0
Author: tchemit
Date: 2013-07-11 15:50:00 +0200 (Thu, 11 Jul 2013)
New Revision: 1284
Url: http://nuiton.org/projects/eugene/repository/revisions/1284
Log:
fixes #2749: Remove topia it in eugene
Modified:
trunk/eugene-maven-plugin/pom.xml
Modified: trunk/eugene-maven-plugin/pom.xml
===================================================================
--- trunk/eugene-maven-plugin/pom.xml 2013-07-11 13:48:09 UTC (rev 1283)
+++ trunk/eugene-maven-plugin/pom.xml 2013-07-11 13:50:00 UTC (rev 1284)
@@ -244,16 +244,16 @@
<configuration>
<pomIncludes>
<pomInclude>evol-308/pom.xml</pomInclude>
- <pomInclude>evol-879/zargo/pom.xml</pomInclude>
- <pomInclude>evol-879/xmi/pom.xml</pomInclude>
- <pomInclude>copyVersionFiles/anomalie163/pom.xml</pomInclude>
+ <!--<pomInclude>evol-879/zargo/pom.xml</pomInclude>-->
+ <!--<pomInclude>evol-879/xmi/pom.xml</pomInclude>-->
+ <!--<pomInclude>copyVersionFiles/anomalie163/pom.xml</pomInclude>-->
<pomInclude>generate/only-zargo/pom.xml</pomInclude>
<pomInclude>generate/only-zargo-xmi/pom.xml</pomInclude>
<pomInclude>generate/all/pom.xml</pomInclude>
<!-- This test should be removed : too much complex to test,... nothing :( -->
<!--<pomInclude>generate/generators/pom.xml</pomInclude>-->
<!--this test used topia and must be move in topia not here-->
- <pomInclude>evol-879/model/pom.xml</pomInclude>
+ <!--<pomInclude>evol-879/model/pom.xml</pomInclude>-->
</pomIncludes>
<postBuildHookScript>verify</postBuildHookScript>
<localRepositoryPath>${basedir}/target/local-repo
1
0
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java 2013-07-11 13:50:16 UTC (rev 1285)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaBuilder.java 2013-07-11 13:53:23 UTC (rev 1286)
@@ -25,9 +25,12 @@
package org.nuiton.eugene.java;
+import com.google.common.base.Preconditions;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.eugene.GeneratorUtil;
+import org.nuiton.eugene.java.extension.ObjectModelAnnotation;
+import org.nuiton.eugene.java.extension.ObjectModelAnnotationParameter;
import org.nuiton.eugene.java.extension.AnnotationsManager;
import org.nuiton.eugene.java.extension.AnnotationsManagerExtension;
import org.nuiton.eugene.java.extension.CodesManager;
@@ -48,6 +51,7 @@
import org.nuiton.eugene.models.object.xml.ObjectModelClassImpl;
import org.nuiton.eugene.models.object.xml.ObjectModelOperationImpl;
+import javax.lang.model.SourceVersion;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;
@@ -295,25 +299,37 @@
*
* @param classifier where the annotation will be added.
* @param element element on which add annotation
* @param annotation annotation to add
*/
- public void addAnnotation(ObjectModelClassifier classifier,
+ public ObjectModelAnnotation addAnnotation(ObjectModelClassifier classifier,
ObjectModelElement element,
- String annotation) {
- if (annotation == null) {
- return;
- }
+ String annotationType) {
+ Preconditions.checkNotNull("Can't add a null annotation");
+ Preconditions.checkArgument(SourceVersion.isName(annotationType),"Annotation type must be a valid type , but was: "+annotationType);
+// if (annotation == null) {
+// return;
+// }
AnnotationsManager manager =
annotationsManagerExtension.getManager(classifier);
- annotation = annotation.trim();
+// annotation = annotation.trim();
+ ObjectModelAnnotation annotation = new ObjectModelAnnotation(annotationType);
manager.addAnnotation(element, annotation);
if (log.isDebugEnabled()) {
log.debug("Add annotation for <" + classifier.getQualifiedName() +
":" + element.getName() + "> : " + annotation);
}
+ return annotation;
}
+ public ObjectModelAnnotation addAnnotationParameter(ObjectModelAnnotation annotation,
+ String parameterName,
+ Object parameterValue) {
+ annotation.addParameter(new ObjectModelAnnotationParameter(parameterName, parameterValue));
+ return annotation;
+ }
+
/**
* Set the superclass of an other class. Only one superclass can be set
* to the class.
@@ -295,25 +299,37 @@
* @param classifier where the annotation will be added.
* @param element element on which add annotation
- * @param annotation annotation to add
+ * @param annotationType type of annotation to add
+ * @return the instanciated annotation
*/
Modified: trunk/eugene/src/main/java/org/nuiton/eugene/java/JavaGenerator.java
===================================================================
--- trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/AnnotationsManagerExtension.java 2013-07-11 13:50:16 UTC (rev 1285)
+++ trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/AnnotationsManagerExtension.java 2013-07-11 13:53:23 UTC (rev 1286)
@@ -30,7 +30,9 @@
import org.nuiton.eugene.models.object.ObjectModelClassifier;
import org.nuiton.eugene.models.object.ObjectModelElement;
+import java.util.Collections;
import java.util.HashMap;
+import java.util.List;
import java.util.Map;
/**
@@ -55,28 +57,28 @@
*/
protected Map<String, AnnotationsManager> managers;
- private static final String[] EMPTY_STRING_ARRAY = new String[]{};
+// private static final String[] EMPTY_STRING_ARRAY = new String[]{};
/**
* Get the registred annotations for the given {@code element} in the
* given {@code classifier}.
- *
+ * <p/>
* <b>Note:</b> The method always returns a {@code none null} value, but
* an empty array when no annotation when no annotation found for the
- * element.
- *
+ * element.
+ *
* @param classifier the classifier where is the element
* @param element the element on which searching annotations
* @return the array of annotation registred or an empty array if none.
*/
- public String[] getAnnotations(ObjectModelClassifier classifier,
- ObjectModelElement element) {
+ public List<ObjectModelAnnotation> getAnnotations(ObjectModelClassifier classifier,
+ ObjectModelElement element) {
AnnotationsManager annotationsManager = getManager(classifier);
- String[] result = null;
+ List<ObjectModelAnnotation> result = null;
if (annotationsManager != null) {
result = annotationsManager.getAnnotations(element);
}
- return result == null ? EMPTY_STRING_ARRAY : result;
+ return result == null ? Collections.<ObjectModelAnnotation>emptyList() : result;
}
/**
Added: trunk/eugene/src/main/java/org/nuiton/eugene/java/extension/ObjectModelAnnotation.java
@@ -55,28 +57,28 @@
* @param classifier the classifier where is the element
- * @param element the element on which searching annotations
- * @return the array of annotation registred or an empty array if none.
+ * @param element the element on which searching annotations
+ * @return the list of annotations registred or an empty list if none.
*/
===================================================================